=============
Sanskrit Text
=============



.. image:: https://img.shields.io/pypi/v/sanskrit-text
        :target: https://pypi.python.org/pypi/sanskrit-text


.. image:: https://readthedocs.org/projects/sanskrit-text/badge/?version=latest
        :target: https://sanskrit-text.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/sanskrit-text
        :target: https://pypi.python.org/pypi/sanskrit-text
        :alt: Python Version Support

.. image:: https://img.shields.io/github/issues/hrishikeshrt/sanskrit-text
        :target: https://github.com/hrishikeshrt/sanskrit-text/issues
        :alt: GitHub Issues

.. image:: https://img.shields.io/github/followers/hrishikeshrt?style=social
        :target: https://github.com/hrishikeshrt
        :alt: GitHub Followers


.. image:: https://img.shields.io/twitter/follow/hrishikeshrt?style=social
        :target: https://twitter.com/hrishikeshrt
        :alt: Twitter Followers



Sanskrit Text (Devanagari) Utility Functions


* Free software: GNU General Public License v3
* Documentation: https://sanskrit-text.readthedocs.io.


Features
========

* Syllabification
* Varṇa Viccheda
* Pratyāhāra Encoding-Decoding
* Uccāraṇa Sthāna Yatna Utility
* Several other utility functions

Install
=======

To install Sanskrit Text, run this command in your terminal:

.. code-block:: console

    $ pip install sanskrit-text

Credits
=======

This package was created with Cookiecutter_ and the `hrishikeshrt/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`hrishikeshrt/cookiecutter-pypackage`: https://github.com/hrishikeshrt/cookiecutter-pypackage
